You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2012/02/14 17:18:50 UTC

svn commit: r1244107 [6/18] - in /commons/proper/math/trunk: ./ src/main/java/org/apache/commons/math/ src/main/java/org/apache/commons/math3/ src/main/java/org/apache/commons/math3/analysis/ src/main/java/org/apache/commons/math3/analysis/function/ sr...

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Plane.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Plane.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Plane.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Plane.java Tue Feb 14 16:17:55 2012
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;
 
-import org.apache.commons.math.exception.MathArithmeticException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.euclidean.oned.Vector1D;
-import org.apache.commons.math.geometry.euclidean.twod.Euclidean2D;
-import org.apache.commons.math.geometry.euclidean.twod.Vector2D;
-import org.apache.commons.math.geometry.euclidean.twod.PolygonsSet;
-import org.apache.commons.math.geometry.partitioning.Embedding;
-import org.apache.commons.math.geometry.partitioning.Hyperplane;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathArithmeticException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.euclidean.oned.Vector1D;
+import org.apache.commons.math3.geometry.euclidean.twod.Euclidean2D;
+import org.apache.commons.math3.geometry.euclidean.twod.Vector2D;
+import org.apache.commons.math3.geometry.euclidean.twod.PolygonsSet;
+import org.apache.commons.math3.geometry.partitioning.Embedding;
+import org.apache.commons.math3.geometry.partitioning.Hyperplane;
+import org.apache.commons.math3.util.FastMath;
 
 /** The class represent planes in a three dimensional space.
  * @version $Id$
@@ -218,7 +218,7 @@ public class Plane implements Hyperplane
      * @param point point of the space (must be a {@link Vector3D
      * Vector3D} instance)
      * @return in-plane point (really a {@link
-     * org.apache.commons.math.geometry.euclidean.twod.Vector2D Vector2D} instance)
+     * org.apache.commons.math3.geometry.euclidean.twod.Vector2D Vector2D} instance)
      * @see #toSpace
      */
     public Vector2D toSubSpace(final Vector<Euclidean3D> point) {
@@ -227,7 +227,7 @@ public class Plane implements Hyperplane
 
     /** Transform an in-plane point into a 3D space point.
      * @param point in-plane point (must be a {@link
-     * org.apache.commons.math.geometry.euclidean.twod.Vector2D Vector2D} instance)
+     * org.apache.commons.math3.geometry.euclidean.twod.Vector2D Vector2D} instance)
      * @return 3D space point (really a {@link Vector3D Vector3D} instance)
      * @see #toSubSpace
      */

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/PolyhedronsSet.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/PolyhedronsSet.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/PolyhedronsSet.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/PolyhedronsSet.java Tue Feb 14 16:17:55 2012
@@ -14,26 +14,26 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;
 
 import java.awt.geom.AffineTransform;
 import java.util.Collection;
 
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.euclidean.oned.Euclidean1D;
-import org.apache.commons.math.geometry.euclidean.twod.Euclidean2D;
-import org.apache.commons.math.geometry.euclidean.twod.SubLine;
-import org.apache.commons.math.geometry.euclidean.twod.Vector2D;
-import org.apache.commons.math.geometry.partitioning.BSPTree;
-import org.apache.commons.math.geometry.partitioning.BSPTreeVisitor;
-import org.apache.commons.math.geometry.partitioning.BoundaryAttribute;
-import org.apache.commons.math.geometry.partitioning.Hyperplane;
-import org.apache.commons.math.geometry.partitioning.Region;
-import org.apache.commons.math.geometry.partitioning.RegionFactory;
-import org.apache.commons.math.geometry.partitioning.SubHyperplane;
-import org.apache.commons.math.geometry.partitioning.Transform;
-import org.apache.commons.math.geometry.partitioning.AbstractRegion;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.euclidean.oned.Euclidean1D;
+import org.apache.commons.math3.geometry.euclidean.twod.Euclidean2D;
+import org.apache.commons.math3.geometry.euclidean.twod.SubLine;
+import org.apache.commons.math3.geometry.euclidean.twod.Vector2D;
+import org.apache.commons.math3.geometry.partitioning.BSPTree;
+import org.apache.commons.math3.geometry.partitioning.BSPTreeVisitor;
+import org.apache.commons.math3.geometry.partitioning.BoundaryAttribute;
+import org.apache.commons.math3.geometry.partitioning.Hyperplane;
+import org.apache.commons.math3.geometry.partitioning.Region;
+import org.apache.commons.math3.geometry.partitioning.RegionFactory;
+import org.apache.commons.math3.geometry.partitioning.SubHyperplane;
+import org.apache.commons.math3.geometry.partitioning.Transform;
+import org.apache.commons.math3.geometry.partitioning.AbstractRegion;
+import org.apache.commons.math3.util.FastMath;
 
 /** This class represents a 3D region: a set of polyhedrons.
  * @version $Id$
@@ -354,7 +354,7 @@ public class PolyhedronsSet extends Abst
                                         tP00.getX(), tP00.getY());
 
                 cachedOriginal  = (Plane) original;
-                cachedTransform = org.apache.commons.math.geometry.euclidean.twod.Line.getTransform(at);
+                cachedTransform = org.apache.commons.math3.geometry.euclidean.twod.Line.getTransform(at);
 
             }
             return ((SubLine) sub).applyTransform(cachedTransform);
@@ -415,7 +415,7 @@ public class PolyhedronsSet extends Abst
 
                 cachedOriginal  = (Plane) original;
                 cachedTransform =
-                    org.apache.commons.math.geometry.euclidean.twod.Line.getTransform(at);
+                    org.apache.commons.math3.geometry.euclidean.twod.Line.getTransform(at);
 
             }
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Rotation.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Rotation.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Rotation.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Rotation.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements rotations in a three-dimensional space.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/RotationOrder.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/RotationOrder.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/RotationOrder.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/RotationOrder.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;
 
 /**
  * This class is a utility representing a rotation order specification

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Segment.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Segment.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Segment.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Segment.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;
 
 
 /** Simple container for a two-points segment.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/SubLine.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/SubLine.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/SubLine.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/SubLine.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;
 
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math.geometry.euclidean.oned.Interval;
-import org.apache.commons.math.geometry.euclidean.oned.IntervalsSet;
-import org.apache.commons.math.geometry.euclidean.oned.Vector1D;
-import org.apache.commons.math.geometry.partitioning.Region.Location;
+import org.apache.commons.math3.geometry.euclidean.oned.Interval;
+import org.apache.commons.math3.geometry.euclidean.oned.IntervalsSet;
+import org.apache.commons.math3.geometry.euclidean.oned.Vector1D;
+import org.apache.commons.math3.geometry.partitioning.Region.Location;
 
 /** This class represents a subset of a {@link Line}.
  * @version $Id$

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/SubPlane.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/SubPlane.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/SubPlane.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/SubPlane.java Tue Feb 14 16:17:55 2012
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;
 
-import org.apache.commons.math.geometry.euclidean.oned.Vector1D;
-import org.apache.commons.math.geometry.euclidean.twod.Euclidean2D;
-import org.apache.commons.math.geometry.euclidean.twod.Vector2D;
-import org.apache.commons.math.geometry.euclidean.twod.PolygonsSet;
-import org.apache.commons.math.geometry.partitioning.AbstractSubHyperplane;
-import org.apache.commons.math.geometry.partitioning.BSPTree;
-import org.apache.commons.math.geometry.partitioning.Hyperplane;
-import org.apache.commons.math.geometry.partitioning.Region;
-import org.apache.commons.math.geometry.partitioning.Side;
-import org.apache.commons.math.geometry.partitioning.SubHyperplane;
+import org.apache.commons.math3.geometry.euclidean.oned.Vector1D;
+import org.apache.commons.math3.geometry.euclidean.twod.Euclidean2D;
+import org.apache.commons.math3.geometry.euclidean.twod.Vector2D;
+import org.apache.commons.math3.geometry.euclidean.twod.PolygonsSet;
+import org.apache.commons.math3.geometry.partitioning.AbstractSubHyperplane;
+import org.apache.commons.math3.geometry.partitioning.BSPTree;
+import org.apache.commons.math3.geometry.partitioning.Hyperplane;
+import org.apache.commons.math3.geometry.partitioning.Region;
+import org.apache.commons.math3.geometry.partitioning.Side;
+import org.apache.commons.math3.geometry.partitioning.SubHyperplane;
 
 /** This class represents a sub-hyperplane for {@link Plane}.
  * @version $Id$
@@ -79,8 +79,8 @@ public class SubPlane extends AbstractSu
             p           = q;
             q           = tmp;
         }
-        final org.apache.commons.math.geometry.euclidean.twod.Line line2D =
-            new org.apache.commons.math.geometry.euclidean.twod.Line(p, q);
+        final org.apache.commons.math3.geometry.euclidean.twod.Line line2D =
+            new org.apache.commons.math3.geometry.euclidean.twod.Line(p, q);
 
         // check the side on the 2D plane
         return getRemainingRegion().side(line2D);
@@ -118,9 +118,9 @@ public class SubPlane extends AbstractSu
             q           = tmp;
         }
         final SubHyperplane<Euclidean2D> l2DMinus =
-            new org.apache.commons.math.geometry.euclidean.twod.Line(p, q).wholeHyperplane();
+            new org.apache.commons.math3.geometry.euclidean.twod.Line(p, q).wholeHyperplane();
         final SubHyperplane<Euclidean2D> l2DPlus =
-            new org.apache.commons.math.geometry.euclidean.twod.Line(q, p).wholeHyperplane();
+            new org.apache.commons.math3.geometry.euclidean.twod.Line(q, p).wholeHyperplane();
 
         final BSPTree<Euclidean2D> splitTree = getRemainingRegion().getTree(false).split(l2DMinus);
         final BSPTree<Euclidean2D> plusTree  = getRemainingRegion().isEmpty(splitTree.getPlus()) ?

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Vector3D.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Vector3D.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Vector3D.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Vector3D.java Tue Feb 14 16:17:55 2012
@@ -15,19 +15,19 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;
 
 import java.io.Serializable;
 import java.text.NumberFormat;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathArithmeticException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.Space;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.MathArrays;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathArithmeticException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.Space;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.MathArrays;
 
 /**
  * This class implements vectors in a three-dimensional space.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Vector3DFormat.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Vector3DFormat.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Vector3DFormat.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/Vector3DFormat.java Tue Feb 14 16:17:55 2012
@@ -15,17 +15,17 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;
 
 import java.text.FieldPosition;
 import java.text.NumberFormat;
 import java.text.ParsePosition;
 import java.util.Locale;
 
-import org.apache.commons.math.exception.MathParseException;
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.VectorFormat;
-import org.apache.commons.math.util.CompositeFormat;
+import org.apache.commons.math3.exception.MathParseException;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.VectorFormat;
+import org.apache.commons.math3.util.CompositeFormat;
 
 /**
  * Formats a 3D vector in components list format "{x; y; z}".

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/threed/package-info.java Tue Feb 14 16:17:55 2012
@@ -21,4 +21,4 @@
  * </p>
  *
  */
-package org.apache.commons.math.geometry.euclidean.threed;
+package org.apache.commons.math3.geometry.euclidean.threed;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Euclidean2D.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Euclidean2D.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Euclidean2D.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Euclidean2D.java Tue Feb 14 16:17:55 2012
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.geometry.euclidean.twod;
+package org.apache.commons.math3.geometry.euclidean.twod;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.geometry.Space;
-import org.apache.commons.math.geometry.euclidean.oned.Euclidean1D;
+import org.apache.commons.math3.geometry.Space;
+import org.apache.commons.math3.geometry.euclidean.oned.Euclidean1D;
 
 /**
  * This class implements a three-dimensional space.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Line.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Line.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Line.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Line.java Tue Feb 14 16:17:55 2012
@@ -14,23 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.twod;
+package org.apache.commons.math3.geometry.euclidean.twod;
 
 import java.awt.geom.AffineTransform;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.euclidean.oned.Euclidean1D;
-import org.apache.commons.math.geometry.euclidean.oned.IntervalsSet;
-import org.apache.commons.math.geometry.euclidean.oned.OrientedPoint;
-import org.apache.commons.math.geometry.euclidean.oned.Vector1D;
-import org.apache.commons.math.geometry.partitioning.Embedding;
-import org.apache.commons.math.geometry.partitioning.Hyperplane;
-import org.apache.commons.math.geometry.partitioning.SubHyperplane;
-import org.apache.commons.math.geometry.partitioning.Transform;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.euclidean.oned.Euclidean1D;
+import org.apache.commons.math3.geometry.euclidean.oned.IntervalsSet;
+import org.apache.commons.math3.geometry.euclidean.oned.OrientedPoint;
+import org.apache.commons.math3.geometry.euclidean.oned.Vector1D;
+import org.apache.commons.math3.geometry.partitioning.Embedding;
+import org.apache.commons.math3.geometry.partitioning.Hyperplane;
+import org.apache.commons.math3.geometry.partitioning.SubHyperplane;
+import org.apache.commons.math3.geometry.partitioning.Transform;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /** This class represents an oriented line in the 2D plane.
 
@@ -309,16 +309,16 @@ public class Line implements Hyperplane<
         originOffset = offset;
     }
 
-    /** Get a {@link org.apache.commons.math.geometry.partitioning.Transform
+    /** Get a {@link org.apache.commons.math3.geometry.partitioning.Transform
      * Transform} embedding an affine transform.
      * @param transform affine transform to embed (must be inversible
      * otherwise the {@link
-     * org.apache.commons.math.geometry.partitioning.Transform#apply(Hyperplane)
+     * org.apache.commons.math3.geometry.partitioning.Transform#apply(Hyperplane)
      * apply(Hyperplane)} method would work only for some lines, and
      * fail for other ones)
      * @return a new transform that can be applied to either {@link
      * Vector2D Vector2D}, {@link Line Line} or {@link
-     * org.apache.commons.math.geometry.partitioning.SubHyperplane
+     * org.apache.commons.math3.geometry.partitioning.SubHyperplane
      * SubHyperplane} instances
      * @exception MathIllegalArgumentException if the transform is non invertible
      */

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/NestedLoops.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/NestedLoops.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/NestedLoops.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/NestedLoops.java Tue Feb 14 16:17:55 2012
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.twod;
+package org.apache.commons.math3.geometry.euclidean.twod;
 
 import java.util.ArrayList;
 import java.util.Iterator;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.geometry.euclidean.oned.IntervalsSet;
-import org.apache.commons.math.geometry.partitioning.Region;
-import org.apache.commons.math.geometry.partitioning.RegionFactory;
-import org.apache.commons.math.geometry.partitioning.SubHyperplane;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.geometry.euclidean.oned.IntervalsSet;
+import org.apache.commons.math3.geometry.partitioning.Region;
+import org.apache.commons.math3.geometry.partitioning.RegionFactory;
+import org.apache.commons.math3.geometry.partitioning.SubHyperplane;
 
 /** This class represent a tree of nested 2D boundary loops.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/PolygonsSet.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/PolygonsSet.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/PolygonsSet.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/PolygonsSet.java Tue Feb 14 16:17:55 2012
@@ -14,26 +14,26 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.twod;
+package org.apache.commons.math3.geometry.euclidean.twod;
 
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 
-import org.apache.commons.math.exception.MathInternalError;
-import org.apache.commons.math.geometry.euclidean.oned.Euclidean1D;
-import org.apache.commons.math.geometry.euclidean.oned.Interval;
-import org.apache.commons.math.geometry.euclidean.oned.IntervalsSet;
-import org.apache.commons.math.geometry.euclidean.oned.Vector1D;
-import org.apache.commons.math.geometry.partitioning.AbstractSubHyperplane;
-import org.apache.commons.math.geometry.partitioning.BSPTree;
-import org.apache.commons.math.geometry.partitioning.BSPTreeVisitor;
-import org.apache.commons.math.geometry.partitioning.BoundaryAttribute;
-import org.apache.commons.math.geometry.partitioning.SubHyperplane;
-import org.apache.commons.math.geometry.partitioning.AbstractRegion;
-import org.apache.commons.math.geometry.partitioning.utilities.AVLTree;
-import org.apache.commons.math.geometry.partitioning.utilities.OrderedTuple;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathInternalError;
+import org.apache.commons.math3.geometry.euclidean.oned.Euclidean1D;
+import org.apache.commons.math3.geometry.euclidean.oned.Interval;
+import org.apache.commons.math3.geometry.euclidean.oned.IntervalsSet;
+import org.apache.commons.math3.geometry.euclidean.oned.Vector1D;
+import org.apache.commons.math3.geometry.partitioning.AbstractSubHyperplane;
+import org.apache.commons.math3.geometry.partitioning.BSPTree;
+import org.apache.commons.math3.geometry.partitioning.BSPTreeVisitor;
+import org.apache.commons.math3.geometry.partitioning.BoundaryAttribute;
+import org.apache.commons.math3.geometry.partitioning.SubHyperplane;
+import org.apache.commons.math3.geometry.partitioning.AbstractRegion;
+import org.apache.commons.math3.geometry.partitioning.utilities.AVLTree;
+import org.apache.commons.math3.geometry.partitioning.utilities.OrderedTuple;
+import org.apache.commons.math3.util.FastMath;
 
 /** This class represents a 2D region: a set of polygons.
  * @version $Id$
@@ -76,7 +76,7 @@ public class PolygonsSet extends Abstrac
      * boundary does not really separate an inside open from an outside
      * open (open having here its topological meaning), then subsequent
      * calls to the {@link
-     * org.apache.commons.math.geometry.partitioning.Region#checkPoint(org.apache.commons.math.geometry.Vector)
+     * org.apache.commons.math3.geometry.partitioning.Region#checkPoint(org.apache.commons.math3.geometry.Vector)
      * checkPoint} method will not be meaningful anymore.</p>
      * <p>If the boundary is empty, the region will represent the whole
      * space.</p>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Segment.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Segment.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Segment.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Segment.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.twod;
+package org.apache.commons.math3.geometry.euclidean.twod;
 
 
 /** Simple container for a two-points segment.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/SubLine.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/SubLine.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/SubLine.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/SubLine.java Tue Feb 14 16:17:55 2012
@@ -14,24 +14,24 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.twod;
+package org.apache.commons.math3.geometry.euclidean.twod;
 
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math.geometry.euclidean.oned.Euclidean1D;
-import org.apache.commons.math.geometry.euclidean.oned.Interval;
-import org.apache.commons.math.geometry.euclidean.oned.IntervalsSet;
-import org.apache.commons.math.geometry.euclidean.oned.OrientedPoint;
-import org.apache.commons.math.geometry.euclidean.oned.Vector1D;
-import org.apache.commons.math.geometry.partitioning.AbstractSubHyperplane;
-import org.apache.commons.math.geometry.partitioning.BSPTree;
-import org.apache.commons.math.geometry.partitioning.Hyperplane;
-import org.apache.commons.math.geometry.partitioning.Region;
-import org.apache.commons.math.geometry.partitioning.Region.Location;
-import org.apache.commons.math.geometry.partitioning.Side;
-import org.apache.commons.math.geometry.partitioning.SubHyperplane;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.geometry.euclidean.oned.Euclidean1D;
+import org.apache.commons.math3.geometry.euclidean.oned.Interval;
+import org.apache.commons.math3.geometry.euclidean.oned.IntervalsSet;
+import org.apache.commons.math3.geometry.euclidean.oned.OrientedPoint;
+import org.apache.commons.math3.geometry.euclidean.oned.Vector1D;
+import org.apache.commons.math3.geometry.partitioning.AbstractSubHyperplane;
+import org.apache.commons.math3.geometry.partitioning.BSPTree;
+import org.apache.commons.math3.geometry.partitioning.Hyperplane;
+import org.apache.commons.math3.geometry.partitioning.Region;
+import org.apache.commons.math3.geometry.partitioning.Region.Location;
+import org.apache.commons.math3.geometry.partitioning.Side;
+import org.apache.commons.math3.geometry.partitioning.SubHyperplane;
+import org.apache.commons.math3.util.FastMath;
 
 /** This class represents a sub-hyperplane for {@link Line}.
  * @version $Id$

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Vector2D.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Vector2D.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Vector2D.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Vector2D.java Tue Feb 14 16:17:55 2012
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.euclidean.twod;
+package org.apache.commons.math3.geometry.euclidean.twod;
 
 import java.text.NumberFormat;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathArithmeticException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.geometry.Space;
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathArithmeticException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.geometry.Space;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /** This class represents a 2D vector.
  * <p>Instances of this class are guaranteed to be immutable.</p>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Vector2DFormat.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Vector2DFormat.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Vector2DFormat.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/Vector2DFormat.java Tue Feb 14 16:17:55 2012
@@ -15,17 +15,17 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.geometry.euclidean.twod;
+package org.apache.commons.math3.geometry.euclidean.twod;
 
 import java.text.FieldPosition;
 import java.text.NumberFormat;
 import java.text.ParsePosition;
 import java.util.Locale;
 
-import org.apache.commons.math.exception.MathParseException;
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.VectorFormat;
-import org.apache.commons.math.util.CompositeFormat;
+import org.apache.commons.math3.exception.MathParseException;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.VectorFormat;
+import org.apache.commons.math3.util.CompositeFormat;
 
 /**
  * Formats a 2D vector in components list format "{x; y}".

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/euclidean/twod/package-info.java Tue Feb 14 16:17:55 2012
@@ -21,4 +21,4 @@
  * </p>
  *
  */
-package org.apache.commons.math.geometry.euclidean.twod;
+package org.apache.commons.math3.geometry.euclidean.twod;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/package-info.java Tue Feb 14 16:17:55 2012
@@ -22,4 +22,4 @@
  * </p>
  *
  */
-package org.apache.commons.math.geometry;
+package org.apache.commons.math3.geometry;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/AbstractRegion.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/AbstractRegion.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/AbstractRegion.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/AbstractRegion.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -22,8 +22,8 @@ import java.util.Comparator;
 import java.util.Iterator;
 import java.util.TreeSet;
 
-import org.apache.commons.math.geometry.Space;
-import org.apache.commons.math.geometry.Vector;
+import org.apache.commons.math3.geometry.Space;
+import org.apache.commons.math3.geometry.Vector;
 
 /** Abstract class for all regions, independently of geometry type or dimension.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/AbstractSubHyperplane.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/AbstractSubHyperplane.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/AbstractSubHyperplane.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/AbstractSubHyperplane.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Space;
-import org.apache.commons.math.geometry.partitioning.SubHyperplane;
+import org.apache.commons.math3.geometry.Space;
+import org.apache.commons.math3.geometry.partitioning.SubHyperplane;
 
 /** This class implements the dimension-independent parts of {@link SubHyperplane}.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BSPTree.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BSPTree.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BSPTree.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BSPTree.java Tue Feb 14 16:17:55 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.Space;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.Space;
+import org.apache.commons.math3.util.FastMath;
 
 /** This class represent a Binary Space Partition tree.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BSPTreeVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BSPTreeVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BSPTreeVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BSPTreeVisitor.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Space;
+import org.apache.commons.math3.geometry.Space;
 
 /** This interface is used to visit {@link BSPTree BSP tree} nodes.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BoundaryAttribute.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BoundaryAttribute.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BoundaryAttribute.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BoundaryAttribute.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Space;
+import org.apache.commons.math3.geometry.Space;
 
 /** Class holding boundary attributes.
  * <p>This class is used for the attributes associated with the

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BoundarySizeVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BoundarySizeVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BoundarySizeVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/BoundarySizeVisitor.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Space;
+import org.apache.commons.math3.geometry.Space;
 
 /** Visitor computing the boundary size.
  * @param <S> Type of the space.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Characterization.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Characterization.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Characterization.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Characterization.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Space;
+import org.apache.commons.math3.geometry.Space;
 
 /** Characterization of a sub-hyperplane.
  * @param <S> Type of the space.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Embedding.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Embedding.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Hyperplane.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Hyperplane.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.Space;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.Space;
 
 /** This interface represents an hyperplane of a space.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Region.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Region.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Region.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Region.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Space;
-import org.apache.commons.math.geometry.Vector;
+import org.apache.commons.math3.geometry.Space;
+import org.apache.commons.math3.geometry.Vector;
 
 /** This interface represents a region of a space as a partition.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/RegionFactory.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/RegionFactory.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/RegionFactory.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/RegionFactory.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Space;
+import org.apache.commons.math3.geometry.Space;
 
 /** This class is a factory for {@link Region}.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Side.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Side.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Side.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Side.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
 /** Enumerate representing the location of an element with respect to an
  * {@link Hyperplane hyperplane} of a space.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/SubHyperplane.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/SubHyperplane.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/SubHyperplane.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/SubHyperplane.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Space;
+import org.apache.commons.math3.geometry.Space;
 
 /** This interface represents the remaining parts of an hyperplane after
  * other parts have been chopped off.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Transform.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Transform.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Transform.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Transform.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.Space;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.Space;
 
 
 /** This interface represents an inversible affine transform in a space.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/AVLTree.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/AVLTree.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning.utilities;
+package org.apache.commons.math3.geometry.partitioning.utilities;
 
 /** This class implements AVL trees.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/OrderedTuple.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/OrderedTuple.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/OrderedTuple.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/OrderedTuple.java Tue Feb 14 16:17:55 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning.utilities;
+package org.apache.commons.math3.geometry.partitioning.utilities;
 
 import java.util.Arrays;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 /** This class implements an ordering operation for T-uples.
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/package-info.java Tue Feb 14 16:17:55 2012
@@ -21,4 +21,4 @@
  * </p>
  *
  */
-package org.apache.commons.math.geometry.partitioning.utilities;
+package org.apache.commons.math3.geometry.partitioning.utilities;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AbstractFieldMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AbstractFieldMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AbstractFieldMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AbstractFieldMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,21 +15,21 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.lang.reflect.Array;
 import java.util.ArrayList;
 import java.util.Arrays;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Basic implementation of {@link FieldMatrix} methods regardless of the underlying storage.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AbstractRealMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AbstractRealMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AbstractRealMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AbstractRealMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,17 +15,17 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.util.ArrayList;
 
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.NotStrictlyPositiveException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Basic implementation of RealMatrix methods regardless of the underlying storage.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AnyMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AnyMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AnyMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/AnyMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/Array2DRowFieldMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/Array2DRowFieldMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/Array2DRowFieldMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/Array2DRowFieldMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,18 +15,18 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Implementation of FieldMatrix<T> using a {@link FieldElement}[][] array to store entries.
@@ -61,7 +61,7 @@ public class Array2DRowFieldMatrix<T ext
      * @param field Field to which the elements belong.
      * @param rowDimension Number of rows in the new matrix.
      * @param columnDimension Number of columns in the new matrix.
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if row or column dimension is not positive.
      */
     public Array2DRowFieldMatrix(final Field<T> field,
@@ -80,7 +80,7 @@ public class Array2DRowFieldMatrix<T ext
      *
      * @param d Data for the new matrix.
      * @throws DimensionMismatchException if {@code d} is not rectangular.
-     * @throws org.apache.commons.math.exception.NullArgumentException if
+     * @throws org.apache.commons.math3.exception.NullArgumentException if
      * {@code d} is {@code null}.
      * @throws NoDataException if there are not at least one row and one column.
      * @see #Array2DRowFieldMatrix(FieldElement[][], boolean)
@@ -99,7 +99,7 @@ public class Array2DRowFieldMatrix<T ext
      * @param field Field to which the elements belong.
      * @param d Data for the new matrix.
      * @throws DimensionMismatchException if {@code d} is not rectangular.
-     * @throws org.apache.commons.math.exception.NullArgumentException if
+     * @throws org.apache.commons.math3.exception.NullArgumentException if
      * {@code d} is {@code null}.
      * @throws NoDataException if there are not at least one row and one column.
      * @see #Array2DRowFieldMatrix(FieldElement[][], boolean)
@@ -121,7 +121,7 @@ public class Array2DRowFieldMatrix<T ext
      * @param copyArray Whether to copy or reference the input array.
      * @throws DimensionMismatchException if {@code d} is not rectangular.
      * @throws NoDataException if there are not at least one row and one column.
-     * @throws org.apache.commons.math.exception.NullArgumentException
+     * @throws org.apache.commons.math3.exception.NullArgumentException
      * if {@code d} is {@code null}.
      * @see #Array2DRowFieldMatrix(FieldElement[][])
      */
@@ -580,7 +580,7 @@ public class Array2DRowFieldMatrix<T ext
      * @param in Data to copy.
      * @throws NoDataException if the input array is empty.
      * @throws DimensionMismatchException if the input array is not rectangular.
-     * @throws org.apache.commons.math.exception.NullArgumentException if
+     * @throws org.apache.commons.math3.exception.NullArgumentException if
      * the input array is {@code null}.
      */
     private void copyIn(final T[][] in) {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/Array2DRowRealMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/Array2DRowRealMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/Array2DRowRealMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/Array2DRowRealMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,16 +15,16 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Implementation of {@link RealMatrix} using a {@code double[][]} array to
@@ -48,7 +48,7 @@ public class Array2DRowRealMatrix extend
      *
      * @param rowDimension Number of rows in the new matrix.
      * @param columnDimension Number of columns in the new matrix.
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if the row or column dimension is not positive.
      */
     public Array2DRowRealMatrix(final int rowDimension, final int columnDimension) {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ArrayFieldVector.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ArrayFieldVector.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ArrayFieldVector.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ArrayFieldVector.java Tue Feb 14 16:17:55 2012
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.Serializable;
 import java.lang.reflect.Array;
 import java.util.Arrays;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
-import org.apache.commons.math.exception.ZeroException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math3.exception.ZeroException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * This class implements the {@link FieldVector} interface with a {@link FieldElement} array.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ArrayRealVector.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ArrayRealVector.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ArrayRealVector.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ArrayRealVector.java Tue Feb 14 16:17:55 2012
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.Serializable;
 import java.util.Arrays;
 import java.util.Iterator;
 
-import org.apache.commons.math.analysis.UnivariateFunction;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.MathArithmeticException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.analysis.UnivariateFunction;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.MathArithmeticException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements the {@link RealVector} interface with a double array.
@@ -708,7 +708,7 @@ public class ArrayRealVector extends Rea
      *
      * @param index Index of first element to be set.
      * @param v Vector containing the values to set.
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the index is inconsistent with the vector size.
      */
     public void setSubVector(int index, double[] v) {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BiDiagonalTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BiDiagonalTransformer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BiDiagonalTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BiDiagonalTransformer.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BlockFieldMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BlockFieldMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BlockRealMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BlockRealMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,17 +15,17 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.Serializable;
 import java.util.Arrays;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Cache-friendly implementation of RealMatrix using a flat arrays to store
@@ -87,7 +87,7 @@ public class BlockRealMatrix extends Abs
      *
      * @param rows  the number of rows in the new matrix
      * @param columns  the number of columns in the new matrix
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if row or column dimension is not positive.
      */
     public BlockRealMatrix(final int rows, final int columns) {
@@ -862,7 +862,7 @@ public class BlockRealMatrix extends Abs
      * @param row the row to be set
      * @param matrix row matrix (must have one row and the same number of columns
      * as the instance)
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the specified row index is invalid.
      * @throws MatrixDimensionMismatchException if the matrix dimensions do
      * not match one instance row.
@@ -944,7 +944,7 @@ public class BlockRealMatrix extends Abs
      * @param column the column to be set
      * @param matrix column matrix (must have one column and the same number of rows
      * as the instance)
-     * @throws org.apache.commons.math.exception.OutOfRangeException
+     * @throws org.apache.commons.math3.exception.OutOfRangeException
      * if the specified column index is invalid.
      * @throws MatrixDimensionMismatchException if the matrix dimensions do
      * not match one instance column.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/CholeskyDecomposition.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/CholeskyDecomposition.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/CholeskyDecomposition.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/CholeskyDecomposition.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ConjugateGradient.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ConjugateGradient.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ConjugateGradient.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/ConjugateGradient.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.ExceptionContext;
-import org.apache.commons.math.util.IterationManager;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.ExceptionContext;
+import org.apache.commons.math3.util.IterationManager;
 
 /**
  * <p>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DecompositionSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DecompositionSolver.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DecompositionSolver.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DecompositionSolver.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 
 
@@ -40,7 +40,7 @@ public interface DecompositionSolver {
      * decomposition algorithm.</p>
      * @param b right-hand side of the equation A &times; X = B
      * @return a vector X that minimizes the two norm of A &times; X - B
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the matrices dimensions do not match.
      * @throws SingularMatrixException
      * if the decomposed matrix is singular.
@@ -52,7 +52,7 @@ public interface DecompositionSolver {
      * decomposition algorithm.</p>
      * @param b right-hand side of the equation A &times; X = B
      * @return a matrix X that minimizes the two norm of A &times; X - B
-     * @throws org.apache.commons.math.exception.DimensionMismatchException
+     * @throws org.apache.commons.math3.exception.DimensionMismatchException
      * if the matrices dimensions do not match.
      * @throws SingularMatrixException
      * if the decomposed matrix is singular.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultFieldMatrixChangingVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultFieldMatrixChangingVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultFieldMatrixChangingVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultFieldMatrixChangingVisitor.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.FieldElement;
 
 /**
  * Default implementation of the {@link FieldMatrixChangingVisitor} interface.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultFieldMatrixPreservingVisitor.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultFieldMatrixPreservingVisitor.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultFieldMatrixPreservingVisitor.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultFieldMatrixPreservingVisitor.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.FieldElement;
+import org.apache.commons.math3.FieldElement;
 
 /**
  * Default implementation of the {@link FieldMatrixPreservingVisitor} interface.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultIterativeLinearSolverEvent.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultIterativeLinearSolverEvent.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultIterativeLinearSolverEvent.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/DefaultIterativeLinearSolverEvent.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.MathUnsupportedOperationException;
+import org.apache.commons.math3.exception.MathUnsupportedOperationException;
 
 /**
  * A default concrete implementation of the abstract class
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Embedding.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Embedding.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
 
-import org.apache.commons.math.geometry.Vector;
-import org.apache.commons.math.geometry.Space;
+import org.apache.commons.math3.geometry.Vector;
+import org.apache.commons.math3.geometry.Space;
 
 /** This interface defines mappers between a space and one of its sub-spaces.
 
@@ -25,10 +25,10 @@ import org.apache.commons.math.geometry.
  * space. The (n-1)-dimension sub-spaces are specific sub-spaces known
  * as {@link Hyperplane hyperplanes}. This interface can be used regardless
  * of the dimensions differences. As an example, {@link
- * org.apache.commons.math.geometry.euclidean.threed.Line Line} in 3D
+ * org.apache.commons.math3.geometry.euclidean.threed.Line Line} in 3D
  * implements Embedding<{@link
  * org.apache.commons.math.geometry.euclidean.threed.Vector3D Vector3D}, {link
  * org.apache.commons.math.geometry.euclidean.oned.Vector1D Vector1D>, i.e. it
  * maps directly dimensions 3 and 1.</p>
 
  * <p>In the 3D euclidean space, hyperplanes are 2D planes, and the 1D
@@ -25,10 +25,10 @@ import org.apache.commons.math.geometry.
  * implements Embedding<{@link
- * org.apache.commons.math.geometry.euclidean.threed.Vector3D Vector3D}, {link
- * org.apache.commons.math.geometry.euclidean.oned.Vector1D Vector1D>, i.e. it
+ * org.apache.commons.math3.geometry.euclidean.threed.Vector3D Vector3D}, {link
+ * org.apache.commons.math3.geometry.euclidean.oned.Vector1D Vector1D>, i.e. it
  * maps directly dimensions 3 and 1.</p>
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Hyperplane.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/Hyperplane.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/package-info.java Tue Feb 14 16:17:55 2012
@@ -19,7 +19,7 @@
  * This package provides classes to implement Binary Space Partition trees.
  *
  * <p>
- * {@link org.apache.commons.math.geometry.partitioning.BSPTree BSP trees}
+ * {@link org.apache.commons.math3.geometry.partitioning.BSPTree BSP trees}
  * are an efficient way to represent parts of space and in particular
  * polytopes (line segments in 1D, polygons in 2D and polyhedrons in 3D)
  * and to operate on them. The main principle is to recursively subdivide
@@ -52,9 +52,9 @@
  * single part, but by several convex ones. This is the property that
  * allows BSP-trees to represent non-convex polytopes despites all parts
  * are convex. The {@link
  * org.apache.commons.math.geometry.partitioning.Region Region} class is
  * devoted to this representation, it is build on top of the {@link
  * org.apache.commons.math.geometry.partitioning.BSPTree BSPTree} class using
  * boolean objects as the leaf nodes attributes to represent the
  * inside/outside property of each leaf part, and also adds various
  * methods dealing with boundaries (i.e. the separation between the
@@ -105,4 +105,4 @@
  *
  *
  */
-package org.apache.commons.math.geometry.partitioning;
+package org.apache.commons.math3.geometry.partitioning;
@@ -52,9 +52,9 @@
  * allows BSP-trees to represent non-convex polytopes despites all parts
  * are convex. The {@link
- * org.apache.commons.math.geometry.partitioning.Region Region} class is
+ * org.apache.commons.math3.geometry.partitioning.Region Region} class is
  * devoted to this representation, it is build on top of the {@link
@@ -52,9 +52,9 @@
  * devoted to this representation, it is build on top of the {@link
- * org.apache.commons.math.geometry.partitioning.BSPTree BSPTree} class using
+ * org.apache.commons.math3.geometry.partitioning.BSPTree BSPTree} class using
  * boolean objects as the leaf nodes attributes to represent the
  * inside/outside property of each leaf part, and also adds various

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/AVLTree.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/geometry/partitioning/utilities/AVLTree.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BlockFieldMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BlockFieldMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,17 +15,17 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Cache-friendly implementation of FieldMatrix using a flat arrays to store
@@ -89,7 +89,7 @@ public class BlockFieldMatrix<T extends 
      * @param field Field to which the elements belong.
      * @param rows Number of rows in the new matrix.
      * @param columns Number of columns in the new matrix.
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if row or column dimension is not positive.
      */
     public BlockFieldMatrix(final Field<T> field, final int rows, final int columns) {
@@ -853,7 +853,7 @@ public class BlockFieldMatrix<T extends 
      * @param row the row to be set
      * @param matrix row matrix (must have one row and the same number of columns
      * as the instance)
      * @throws org.apache.commons.math.exception.OutOfRangeException if the
      * specified row index is invalid.
      * @throws MatrixDimensionMismatchException if the matrix dimensions do
      * not match one instance row.
@@ -935,7 +935,7 @@ public class BlockFieldMatrix<T extends 
      * @param column Column to be set.
      * @param matrix Column matrix (must have one column and the same number of rows
      * as the instance).
-     * @throws org.apache.commons.math.exception.OutOfRangeException if
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if
      * the specified column index is invalid.
      * @throws MatrixDimensionMismatchException if the matrix dimensions do
      * not match one instance column.
@@ -853,7 +853,7 @@ public class BlockFieldMatrix<T extends 
      * @param matrix row matrix (must have one row and the same number of columns
      * as the instance)
-     * @throws org.apache.commons.math.exception.OutOfRangeException if the
+     * @throws org.apache.commons.math3.exception.OutOfRangeException if the
      * specified row index is invalid.
      * @throws MatrixDimensionMismatchException if the matrix dimensions do

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BlockRealMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/BlockRealMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================